@@ -7,7 +7,9 @@ my $mc = Padre::Swarm::Transport::Multicast->new;
 #$mc->subscribe_channel( 12000 );
 $mc->start;
 
-while ( <STDIN> ) {
+while ( 1 ) {
 	chomp;
+        sleep 1;
+ 	$_ = '{}';
 	$mc->tell_channel( 12000, $_ );
 }
