@@ -1,49 +1,39 @@
-
 package Padre::Plugin::Swarm;
 
 use 5.008;
 use strict;
 use warnings;
-use File::Spec             ();
-use Wx::Socket             ();
-use Padre::Constant        ();
-use Padre::Wx              ();
-use Padre::Plugin          ();
-use Padre::Wx::Icon        ();
-use Padre::Swarm::Geometry ();
+use File::Spec      ();
+use Padre::Constant ();
+use Padre::Wx       ();
+use Padre::Plugin   ();
+use Padre::Wx::Icon ();
 use Padre::Logger;
 
-
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 our @ISA     = 'Padre::Plugin';
 
-use Class::XSAccessor 
+use Class::XSAccessor {
 	accessors => {
-		geometry => 'geometry',
-		resources=> 'resources',
-		editor   => 'editor',
-		chat     => 'chat',
-		config   => 'config',
-		wx => 'wx',
-
-		global => 'global',
-		local  => 'local',
-	};
-	
-
+		geometry  => 'geometry',
+		resources => 'resources',
+		editor    => 'editor',
+		chat      => 'chat',
+		config    => 'config',
+		wx        => 'wx',
+		global    => 'global',
+		local     => 'local',
+	}
+};
 
 sub connect {
 	my $self = shift;
 
-	# For now - use global, 
+	# For now - use global,
 	#  could be Padre::Plugin::Swarm::Transport::Local::Multicast
 	#   based on preferences
 	$self->global->enable;
 	$self->local->enable;
-	
-	
-
-	
 }
 
 sub disconnect {
@@ -51,7 +41,6 @@ sub disconnect {
 
 	$self->global->disable;
 	$self->local->disable;
-
 }
 
 sub NOTsend {
@@ -67,7 +56,6 @@ sub NOTsend {
 
 sub on_transport_connect {
 	my ($self) = @_;
-	
 	TRACE( "Swarm transport connected" ) if DEBUG;
 	$self->send(
 		{ type=>'announce', service=>'swarm' }
@@ -85,32 +73,29 @@ sub on_transport_disconnect {
 
 }
 
-
-sub on_recv { 
+sub on_recv {
 	my $self = shift;
 	# my $universe = shift;
 	my $message = shift;
-	
+
 	TRACE( "on_recv handler for " . $message->type ) if DEBUG;
 	# TODO can i use 'SWARM' instead?
-	my $lock = $self->main->lock('UPDATE'); 
+	my $lock = $self->main->lock('UPDATE');
 	my $handler = 'accept_' . $message->type;
-	
+
 	if ( $self->can( $handler ) ) {
 		TRACE( $handler ) if DEBUG;
 		eval { $self->$handler( $message ); };
 	}
-	
+
 	# TODO - make these parts use the message event! srsly
 	$self->geometry->On_SwarmMessage( $message );
-	
-	#
-	my $data = Storable::freeze( $message ); 
+
+	my $data = Storable::freeze( $message );
 	Wx::PostEvent(
                 $self->wx,
                 Wx::PlThreadEvent->new( -1, $self->message_event , $data ),
         ) if $self->message_event;
-
 }
 
 sub accept_disco {
@@ -127,12 +112,12 @@ sub identity {
 		# Default to your padre nickname.
 		my $nickname = $config->identity_nickname;
 		#my $id = $$ . time(). $config . $self;
-		
+
 		unless ( $nickname ) {
 			$nickname = "Anonymous_$$";
 		}
-		$self->{identity} = 
-			Padre::Swarm::Identity->new( 
+		$self->{identity} =
+			Padre::Swarm::Identity->new(
 				nickname => $nickname,
 				service => 'swarm',
 			);
@@ -168,7 +153,7 @@ sub plugin_icons_directory {
 
 sub plugin_icon {
 	my $class = shift;
-	Padre::Wx::Icon::find( 
+	Padre::Wx::Icon::find(
 		'status/padre-plugin-swarm',
 		{ icons => $class->plugin_icons_directory },
 	);
@@ -181,7 +166,7 @@ sub plugin_large_icon {
 		{
 			size  => '128x128',
 			icons => $class->plugin_icons_directory,
-		} 
+		}
 	);
 	return $icon;
 }
@@ -196,14 +181,16 @@ sub menu_plugins_simple {
 # Singleton (I think)
 SCOPE: {
 	my $instance;
-	sub new { $instance = shift->SUPER::new(@_); }
+
+	sub new {
+		$instance = shift->SUPER::new(@_);
+	}
 
 	sub instance { $instance };
 
 	sub plugin_enable {
-
 		my $self   = shift;
-		# TODO - enforce singleton!! 
+		# TODO - enforce singleton!!
 		$instance  = $self;
 		my $wxobj = new Wx::Panel $self->main;
 		$self->wx( $wxobj );
@@ -216,37 +203,38 @@ SCOPE: {
 		require Padre::Plugin::Swarm::Transport::Global::WxSocket;
 		require Padre::Plugin::Swarm::Transport::Local::Multicast;
 		require Padre::Plugin::Swarm::Universe;
-		
+		require Padre::Swarm::Geometry;
+
 		my $config = $self->bootstrap_config;
 		$self->config( $config );
-		
+
 		my $geo = Padre::Swarm::Geometry->new;
 		$self->geometry( $geo );
-		
+
 		my $u_global = Padre::Plugin::Swarm::Universe->new;
 		my $u_local  = Padre::Plugin::Swarm::Universe->new;
 		$self->global($u_global);
 		$self->local($u_local);
-		
+
 		## Instance the transport but do not connect them - yet
-		my $t_global = 
+		my $t_global =
 		Padre::Plugin::Swarm::Transport::Global::WxSocket->new(
 			token => $self->config->{token},
 			wx => $self->wx,
 		);
 		$u_global->transport($t_global);
-	
-		my $t_local = 
+
+		my $t_local =
 			Padre::Plugin::Swarm::Transport::Local::Multicast->new(
 				token => $self->config->{token},
 				wx    => $self->wx,
 			);
 		$u_local->transport($t_local);
-		
-		
+
+
 		$u_global->geometry($geo);
 		$u_local->geometry($geo);
-		
+
 		## Should this be in global or local?
 		my $editor = Padre::Plugin::Swarm::Wx::Editor->new(
 			transport => $t_global,
@@ -260,50 +248,50 @@ SCOPE: {
 		);
 		$self->resources( $g_directory );
 		$u_global->resources($g_directory);
-		
+
 		my $g_chat = Padre::Plugin::Swarm::Wx::Chat->new( $self->main,
 				label => 'Global', transport => $self->global->transport
 		 );
 		$u_global->chat($g_chat);
-		
-		my $l_chat = Padre::Plugin::Swarm::Wx::Chat->new( 
+
+		my $l_chat = Padre::Plugin::Swarm::Wx::Chat->new(
 				$self->main,
-				label => 'Local', 
+				label => 'Local',
 				transport => $self->local->transport
 		 );
 		$u_local->chat($l_chat);
-		
-		
+
+
 		$self->connect();
 
-		
+
 		1;
 	}
 
 	sub plugin_disable {
 		my $self = shift;
-		
+
 		eval {
 				$self->global->disable;
 		};
 		if ($@) {
 			TRACE( "Disable global failed $@" ) if DEBUG;
 		}
-		
+
 		eval { $self->local->disable; };
 		if ($@) {
 			TRACE( "Disable local failed $@" ) if DEBUG;
 		}
-		
+
 		$self->editor->disable;
 		$self->editor(undef);
-		
+
 		$self->wx->Destroy;
 		$self->wx(undef);
-		
+
 		undef $instance;
-	
-		
+
+
 	}
 }
 
@@ -312,16 +300,16 @@ sub plugin_preferences {
 	my $wx = shift;
 	if  ( $self->instance ) {
 		die "Please disable plugin before editing preferences\n";
-		
+
 	}
-	eval { 
+	eval {
 		my $dialog = Padre::Plugin::Swarm::Wx::Preferences->new($wx);
 		$dialog->ShowModal;
 		$dialog->Destroy;
 	};
-	
+
 	TRACE( "Preferences error $@" ) if DEBUG && $@;
-	
+
 	return;
 }
 
@@ -344,10 +332,10 @@ sub bootstrap_config {
 		'swarm.perlide.org',
 		$VERSION
 		) ;
-		
+
 	$self->config_write( $config );
 	return $config;
-	
+
 }
 
 sub editor_enable {
@@ -370,7 +358,7 @@ sub show_about {
 		{
 			size  => '128x128',
 			icons => $self->plugin_icons_directory,
-		} 
+		}
 	);
 
 	my $about = Wx::AboutDialogInfo->new;
