@@ -9,7 +9,7 @@ use Class::XSAccessor
     accessors => {
         editors => 'editors',
         resources=> 'resources',
-        
+        transport => 'transport',
     };
     
 =pod
@@ -46,8 +46,6 @@ respond to.
 =cut
 
 
-# TODO Register events , catch swarm messages and apply them to open documents
-# 
 sub new {
 	my $class = shift;
 	my %args  = @_;
@@ -59,20 +57,12 @@ sub new {
 
 sub enable {
 	my $self = shift;
-	eval {
-	Wx::Event::EVT_COMMAND(
-	    $self->plugin->wx,
-	    -1,
-	    $self->plugin->message_event,
-	    sub { $self->on_swarm_message(@_) },
-	);
-	};
-	
-	# TODO - when enabled - announce the open editor tabs!
+
 	foreach my $editor ( $self->plugin->main->editors ) {
-	    $self->editor_enable( $editor, $editor->{Document} )
+	    eval{ $self->editor_enable( $editor, $editor->{Document} ) };
+		TRACE( "Failed to enable editor - $@" ) if DEBUG && $@;
 	}
-	TRACE( "Failed to enable editor - $@" ) if DEBUG && $@;
+
 }
 
 sub disable {}
@@ -84,7 +74,7 @@ sub editor_enable {
 	return unless $document && $document->filename;
 	
         eval  {
-	    $self->plugin->send(
+	    $self->transport->send(
 		{ 
 			type => 'promote', service => 'editor',
 			resource => $document->filename
@@ -92,6 +82,7 @@ sub editor_enable {
 	    );
 	
 	};
+	TRACE( "Failed to send $@" ) if DEBUG;
 	
 	$self->editors->{ refaddr $editor } = $editor;
 	$self->resources->{ $document->filename } = $document;
@@ -108,7 +99,7 @@ sub editor_disable {
 	return unless $document->filename;
 	
 	eval {
-            $self->plugin->send( {
+            $self->transport->send( {
                 type => 'destroy' , 
                 service => 'editor',
                 resource => $document->filename}
@@ -122,14 +113,8 @@ sub editor_disable {
 
 
 # Swarm event handler
-sub on_swarm_message {
-	my ($self,$main,$event) = @_;
-	my $data = $event->GetData;
-	my $message = Storable::thaw( $data );
-	# TODO - perform the geometry manipulation here and only update when 
-	# necessary
-
-	
+sub on_recv {
+	my ($self,$message) = @_;
 	my $handler = 'accept_' . $message->{type};
 	TRACE( $handler ) if DEBUG;
 	if ($self->can($handler)) {
@@ -137,9 +122,6 @@ sub on_swarm_message {
 		TRACE( "$handler failed - $@" ) if DEBUG && $@;
 	}
 	
-	# don't hog the troff
-	$event->Skip(1);
-	
 }
 # message handlers
 
@@ -184,7 +166,7 @@ sub accept_gimme {
 
 	if ( exists $self->resources->{$r} ) {
 		my $document = $self->resources->{$r};
-		$self->plugin->send(
+		$self->transport->send(
 		    { 	type => 'openme',
 			service => 'editor',
 			body => $document->text_get,
@@ -207,12 +189,18 @@ sub accept_disco {
 	my ($self,$message) = @_;
 	TRACE( $message->{from} . " disco" ) if DEBUG;
 	foreach my $doc ( values %{ $self->resources } ) {
+		TRACE( "Promoting " . $doc->filename ) if DEBUG;
 	    eval  {
-		$self->plugin->send(
-		{ type => 'promote', service => 'editor',
-		    resource => $doc->filename }
-		);
+		$self->transport->send(
+				{ type => 'promote', service => 'editor',
+				  resource => $doc->filename }
+				);
 	    };
+	    
+	    if ($@) {
+			TRACE("Failed to send - $@" ) if DEBUG;
+		}
+	    
 	}
 	
 }
